@@ -1,7 +1,7 @@
 package Markdown::To::POD;
 
-our $DATE = '2014-07-28'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-09-26'; # DATE
+our $VERSION = '0.05'; # VERSION
 # ABSTRACT: Convert Markdown syntax to POD
 
 use 5.010001;
@@ -1354,9 +1354,6 @@ sub _EncodeBackslashEscapes {
 sub _DoAutoLinks {
     my ($self, $text) = @_;
 
-    #$text =~ s{<((https?|ftp):[^'">\s]+)>}{<a href="$1">$1</a>}gi;
-    #$text =~ s{<((https?|ftp):[^'">\s]+)>}{__podfmt(L => $1)}egi;
-
     # Email addresses: <address@domain.foo>
     $text =~ s{
         <
@@ -1368,7 +1365,23 @@ sub _DoAutoLinks {
         )
         >
     }{
-        $self->_EncodeEmailAddress( $self->_UnescapeSpecialChars($1) );
+        #$self->_EncodeEmailAddress( $self->_UnescapeSpecialChars($1) );
+        __podfmt(L => "mailto:$1");
+    }egix;
+
+    #$text =~ s{<((https?|ftp):[^'">\s]+)>}{<a href="$1">$1</a>}gi;
+    $text =~ s{<((https?|ftp):[^'">\s]+)>}{__podfmt(L => $1)}egi;
+
+    # pm: and prog:
+    $text =~ s{
+        <
+        (?:pm|prog):(?://?)?
+        (
+            [\w-]+(?:::[\w-]+)*
+        )
+        >
+    }{
+        __podfmt(L => $1);
     }egix;
 
     return $text;
@@ -1527,7 +1540,7 @@ Markdown::To::POD - Convert Markdown syntax to POD
 
 =head1 VERSION
 
-This document describes version 0.04 of Markdown::To::POD (from Perl distribution Markdown-To-POD), released on 2014-07-28.
+This document describes version 0.05 of Markdown::To::POD (from Perl distribution Markdown-To-POD), released on 2016-09-26.
 
 =head1 SYNOPSIS
 
@@ -1582,67 +1595,6 @@ element and set its value to C<1>, C<on> or C<yes>:
 
 The extra C<markdown> attribute will be stripped when generating the output.
 
-=head1 OPTIONS
-
-Text::Markdown supports a number of options to its processor which control
-the behaviour of the output document.
-
-These options can be supplied to the constructor, or in a hash within
-individual calls to the L</markdown> method. See the SYNOPSIS for examples
-of both styles.
-
-The options for the processor are:
-
-=over
-
-=item empty_element_suffix
-
-This option controls the end of empty element tags:
-
-    '/>' for XHTML (default)
-    '>' for HTML
-
-=item tab_width
-
-Controls indent width in the generated markup. Defaults to 4.
-
-=item trust_list_start_value
-
-If true, ordered lists will use the first number as the starting point for
-numbering.  This will let you pick up where you left off by writing:
-
-  1. foo
-  2. bar
-
-  some paragraph
-
-  3. baz
-  6. quux
-
-(Note that in the above, quux will be numbered 4.)
-
-=back
-
-=head1 METHODS
-
-=head2 new
-
-A simple constructor, see the SYNTAX and OPTIONS sections for more information.
-
-=head2 markdown_to_pod
-
-The main function as far as the outside world is concerned. See the SYNOPSIS
-for details on use.
-
-=head2 urls
-
-Returns a reference to a hash with the key being the markdown reference
-and the value being the URL.
-
-Useful for building scripts which preprocess a list of links before the
-main content. See F<t/05options.t> for an example of this hashref being
-passed back into the markdown method to create links.
-
 =head1 OTHER IMPLEMENTATIONS
 
 Markdown has been re-implemented in a number of languages, and with a number of additions.
@@ -1764,6 +1716,67 @@ liability, whether in contract, strict liability, or tort (including
 negligence or otherwise) arising in any way out of the use of this
 software, even if advised of the possibility of such damage.
 
+=head1 METHODS
+
+=head2 new
+
+A simple constructor, see the SYNTAX and OPTIONS sections for more information.
+
+=head2 markdown_to_pod
+
+The main function as far as the outside world is concerned. See the SYNOPSIS
+for details on use.
+
+=head2 urls
+
+Returns a reference to a hash with the key being the markdown reference
+and the value being the URL.
+
+Useful for building scripts which preprocess a list of links before the
+main content. See F<t/05options.t> for an example of this hashref being
+passed back into the markdown method to create links.
+
+=head1 OPTIONS
+
+Text::Markdown supports a number of options to its processor which control
+the behaviour of the output document.
+
+These options can be supplied to the constructor, or in a hash within
+individual calls to the L</markdown> method. See the SYNOPSIS for examples
+of both styles.
+
+The options for the processor are:
+
+=over
+
+=item empty_element_suffix
+
+This option controls the end of empty element tags:
+
+    '/>' for XHTML (default)
+    '>' for HTML
+
+=item tab_width
+
+Controls indent width in the generated markup. Defaults to 4.
+
+=item trust_list_start_value
+
+If true, ordered lists will use the first number as the starting point for
+numbering.  This will let you pick up where you left off by writing:
+
+  1. foo
+  2. bar
+
+  some paragraph
+
+  3. baz
+  6. quux
+
+(Note that in the above, quux will be numbered 4.)
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Markdown-To-POD>.
@@ -1782,11 +1795,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
